@@ -1,4 +1,4 @@
-__version__ = "0.2.2"
+__version__ = "0.4.0"
 
 from docutils import nodes
 from jupyter_sphinx.ast import (  # noqa: F401
@@ -7,7 +7,6 @@ from jupyter_sphinx.ast import (  # noqa: F401
     JupyterCell,
 )
 
-# from ipywidgets import embed
 from pathlib import Path
 
 from .parser import (
@@ -18,6 +17,9 @@ from .parser import (
     CellOutputBundleNode,
 )
 from .transform import CellOutputsToNodes
+from .nb_glue import glue  # noqa: F401
+from .nb_glue.domain import NbGlueDomain
+from .nb_glue.transform import PasteNodesToDocutils
 
 
 def static_path(app):
@@ -35,6 +37,10 @@ def update_togglebutton_classes(app, config):
         config.togglebutton_selector += f", {selector}"
 
 
+def save_glue_cache(app, env):
+    NbGlueDomain.from_env(env).write_cache()
+
+
 def setup(app):
     """Initialize Sphinx extension."""
     # Sllow parsing ipynb files
@@ -82,13 +88,18 @@ def setup(app):
     )
 
     # Register our post-transform which will convert output bundles to nodes
+    app.add_post_transform(PasteNodesToDocutils)
     app.add_post_transform(CellOutputsToNodes)
 
     app.connect("builder-inited", static_path)
     app.connect("config-inited", update_togglebutton_classes)
+    app.connect("env-updated", save_glue_cache)
     app.add_css_file("mystnb.css")
     # We use `execute` here instead of `jupyter-execute`
     app.add_directive("execute", JupyterCell)
     app.setup_extension("jupyter_sphinx")
+    app.add_domain(NbGlueDomain)
 
-    return {"version": __version__, "parallel_read_safe": True}
+    # TODO need to deal with key clashes in NbGlueDomain.merge_domaindata
+    # before this is parallel_read_safe
+    return {"version": __version__, "parallel_read_safe": False}
